@@ -36,12 +36,10 @@
 
 #include <KMessageBox>
 #include <KLocalizedString>
-#include <KIconLoader>
 #include <KActionCollection>
 #include <KIO/RenameDialog>
 #include <KIO/DeleteJob>
 #include <KSharedConfig>
-#include <KPluginInfo>
 #include <KConfigDialog>
 #include <KPluginMetaData>
 
@@ -629,9 +627,9 @@ QList<TransferFactory*> KGet::factories()
     return m_transferFactories;
 }
 
-KPluginInfo::List KGet::pluginInfos()
+QVector<KPluginMetaData> KGet::plugins()
 {
-    return m_pluginInfoList;
+    return m_pluginList;
 }
 
 TransferFactory * KGet::factory(TransferHandler * transfer)
@@ -814,8 +812,8 @@ void KGet::calculateGlobalUploadLimit()
 // ------ STATIC MEMBERS INITIALIZATION ------
 TransferTreeModel * KGet::m_transferTreeModel;
 TransferTreeSelectionModel * KGet::m_selectionModel;
+QVector<KPluginMetaData> KGet::m_pluginList;
 QList<TransferFactory *> KGet::m_transferFactories;
-KPluginInfo::List KGet::m_pluginInfoList;
 TransferGroupScheduler * KGet::m_scheduler = nullptr;
 MainWindow * KGet::m_mainWindow = nullptr;
 KUiServerJobs * KGet::m_jobManager = nullptr;
@@ -1144,10 +1142,10 @@ QUrl KGet::getValidDestUrl(const QUrl& destDir, const QUrl &srcUrl)
 void KGet::loadPlugins()
 {
     m_transferFactories.clear();
-    m_pluginInfoList.clear();
+    m_pluginList.clear();
 
     // TransferFactory plugins
-    const QVector<KPluginMetaData> offers = KPluginLoader::findPlugins(QStringLiteral("kget"), [](const KPluginMetaData& md) {
+    const QVector<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("kget"), [](const KPluginMetaData& md) {
         return md.value(QStringLiteral("X-KDE-KGet-framework-version")) == QString::number(FrameworkVersion) &&
             md.value(QStringLiteral("X-KDE-KGet-rank")).toInt() > 0 &&
             md.value(QStringLiteral("X-KDE-KGet-plugintype")) == QStringLiteral("TransferFactory");
@@ -1175,11 +1173,8 @@ void KGet::loadPlugins()
 
     for (const KPluginMetaData& md : qAsConst(sortedOffers))
     {
-        KPluginInfo info(md);
-        info.load(plugins);
-        m_pluginInfoList.prepend(info);
-
-        if (!info.isPluginEnabled())
+        m_pluginList.prepend(md);
+        if (!plugins.readEntry(md.pluginId() + QLatin1String("Enabled"), md.isEnabledByDefault()))
         {
             qCDebug(KGET_DEBUG) << "TransferFactory plugin (" << md.fileName()
                              << ") found, but not enabled";
@@ -1189,7 +1184,7 @@ void KGet::loadPlugins()
         KGetPlugin* plugin = loadPlugin(md);
         if (plugin != nullptr)
         {
-            const QString pluginName = info.name();
+            const QString pluginName = md.name();
 
             pluginList.prepend(plugin);
             qCDebug(KGET_DEBUG) << "TransferFactory plugin (" << md.fileName()
@@ -1238,14 +1233,15 @@ void KGet::setHasNetworkConnection(bool hasConnection)
 
 KGetPlugin* KGet::loadPlugin(const KPluginMetaData& md)
 {
-    KPluginFactory* factory = KPluginLoader(md.fileName()).factory();
-    if (factory) {
-        return factory->create<TransferFactory>(KGet::m_mainWindow);
+    const KPluginFactory::Result<TransferFactory> result = KPluginFactory::instantiatePlugin<TransferFactory>(md, KGet::m_mainWindow);
+
+    if (result) {
+        return result.plugin;
     } else {
         KGet::showNotification(m_mainWindow, "error",
-                               i18n("Plugin loader could not load the plugin: %1.", md.fileName()),
+                               i18n("Plugin loader could not load the plugin %1: %2.", md.fileName(), result.errorString),
                                "dialog-info");
-        qCCritical(KGET_DEBUG) << "KPluginFactory could not load the plugin:" << md.fileName();
+        qCCritical(KGET_DEBUG) << "KPluginFactory could not load the plugin" << md.fileName() << result.errorText;
         return nullptr;
     }
 }
@@ -1277,7 +1273,7 @@ bool KGet::safeDeleteFile( const QUrl& url )
 KNotification *KGet::showNotification(QWidget *parent, const QString &eventType,
                             const QString &text, const QString &icon, const QString &title, const KNotification::NotificationFlags &flags)
 {
-    return KNotification::event(eventType, title, text, QIcon::fromTheme(icon).pixmap(KIconLoader::SizeMedium), parent, flags);
+    return KNotification::event(eventType, title, text, icon, parent, flags);
 }
 
 GenericObserver::GenericObserver(QObject *parent)
@@ -1285,9 +1281,14 @@ GenericObserver::GenericObserver(QObject *parent)
     m_save(nullptr),
     m_finishAction(nullptr)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QNetworkInformation::load(QNetworkInformation::Feature::Reachability);
+    KGet::setHasNetworkConnection(QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online);
+#else
     //check if there is a connection
     KGet::setHasNetworkConnection(m_networkConfig.isOnline());
-    
+#endif
+
     connect(KGet::model(), &TransferTreeModel::groupRemovedEvent, this, &GenericObserver::groupRemovedEvent);
     connect(KGet::model(), SIGNAL(transfersAddedEvent(QList<TransferHandler*>)),
                            SLOT(transfersAddedEvent(QList<TransferHandler*>)));
@@ -1300,8 +1301,13 @@ GenericObserver::GenericObserver(QObject *parent)
                            SLOT(groupsChangedEvent(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>)));
     connect(KGet::model(), &TransferTreeModel::transferMovedEvent,
                            this, &GenericObserver::transferMovedEvent);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect(&m_networkConfig, &QNetworkConfigurationManager::onlineStateChanged,
                          this, &GenericObserver::slotNetworkStatusChanged);
+#else
+    connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, &GenericObserver::slotNetworkStatusChanged);
+#endif
 
 }
 
@@ -1389,7 +1395,7 @@ void GenericObserver::transfersChangedEvent(QMap<TransferHandler*, Transfer::Cha
             } else if (transfer->status() == Job::Aborted && transfer->error().type != Job::AutomaticRetry) {
                 KNotification * notification = KNotification::event("error", i18n("Error"), i18n("<p>There has been an error in the following transfer:</p><p style=\"font-size: small;\">%1</p>"
                                             "<p>The error message is:</p><p style=\"font-size: small;\">%2</p>", transfer->source().toString(), transfer->error().text), 
-                                             transfer->error().pixmap, KGet::m_mainWindow, KNotification::CloseOnTimeout);
+                                             transfer->error().iconName, KGet::m_mainWindow, KNotification::CloseOnTimeout);
                 if (transfer->error().type == Job::ManualSolve) {
                     m_notifications.insert(notification, transfer);
                     notification->setActions(QStringList() << i18n("Resolve"));
@@ -1496,10 +1502,17 @@ void GenericObserver::slotNotificationClosed()
         m_notifications.remove(notification);
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void GenericObserver::slotNetworkStatusChanged(bool online)
 {
     KGet::setHasNetworkConnection(online);
 }
+#else
+void GenericObserver::slotNetworkStatusChanged(QNetworkInformation::Reachability reachability)
+{
+    KGet::setHasNetworkConnection(reachability == QNetworkInformation::Reachability::Online);
+}
+#endif
 
 void GenericObserver::groupsChangedEvent(QMap<TransferGroupHandler*, TransferGroup::ChangesFlags> groups)
 {
